<?php
namespace MascotCoreAonsilElementor\Widgets;

use Elementor\Widget_Base;
use Elementor\Controls_Manager;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

/**
 * Elementor Hello World
 *
 * Elementor widget for hello world.
 *
 * @since 1.0.0
 */
class TM_Elementor_Features_Box extends Widget_Base {

  /**
   * Retrieve the widget name.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget name.
   */
  public function get_name() {
	return 'tm-ele-features-box';
  }

  /**
   * Retrieve the widget title.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget title.
   */
  public function get_title() {
	return esc_html__( 'Features Box', 'mascot-core-elementor' );
  }

  /**
   * Retrieve the widget icon.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return string Widget icon.
   */
  public function get_icon() {
	return 'tm-elementor-widget-icon';
  }

  /**
   * Retrieve the list of categories the widget belongs to.
   *
   * Used to determine where to display the widget in the editor.
   *
   * Note that currently Elementor supports only one category.
   * When multiple categories passed, Elementor uses the first one.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget categories.
   */
  public function get_categories() {
	return [ 'tm' ];
  }

  /**
   * Retrieve the list of scripts the widget depended on.
   *
   * Used to set scripts dependencies required to run the widget.
   *
   * @since 1.0.0
   *
   * @access public
   *
   * @return array Widget scripts dependencies.
   */
  public function get_script_depends() {
	return [ 'mascot-core-hellojs' ];
  }

  /**
   * Register the widget controls.
   *
   * Adds different input fields to allow the user to change and customize the widget settings.
   *
   * @since 1.0.0
   *
   * @access protected
   */
	protected function _register_controls() {

		$this->start_controls_section(
			'general',
			[
				'label' => esc_html__( 'General', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_control(
			'custom_css_class',
			[
				'label' => esc_html__( "Custom CSS class", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
			]
		);
		$this->add_control(
			'design_style',
			[
				'label' => esc_html__( "Design Style", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'current-theme-style1' => esc_html__( 'Current Theme Style 1', 'mascot-core-elementor' ),
					'current-theme-style2' => esc_html__( 'Current Theme Style 2', 'mascot-core-elementor' ),
				],
				'default' => 'current-theme-style1'
			]
		);
		$this->add_control(
			'featured_image',
			[
				'label' => esc_html__( "Featured Image", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				"description" => esc_html__( "Upload featured image", 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'featured_image_hover',
			[
				'label' => esc_html__( "Featured Image on Hover", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::MEDIA,
				"description" => esc_html__( "Upload featured image on Hover", 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'predefined_image_size',
			[
				'label' => esc_html__( "Choose Featured Image Size", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => mascot_core_aonsil_elementor_get_available_image_sizes(),
				'default' => 'full',
			]
		);




		$this->add_control(
			'title',
			[
				'label' => esc_html__( "Title", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::TEXT,
				'default' => esc_html__( "This is a section title", 'mascot-core-elementor' ),
				"description" => esc_html__( 'Eg: Projects Completed', 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'link_url',
			[
				'label' => esc_html__( "Link URL", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::URL,
				'description'   => esc_html__( 'Add link to Button & Title.', 'mascot-core-elementor' ),
			]
		);
		$this->add_control(
			'content',
			[
				'label' => esc_html__( "Paragraph", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::WYSIWYG,
				'default' => esc_html__( "Write a short description, that will describe the title or something informational and useful.", 'mascot-core-elementor' ),
			]
		);

		$this->end_controls_section();






		$this->start_controls_section(
			'content_options',
			[
				'label' => esc_html__( 'Content Options', 'mascot-core-elementor' ),
				'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
			]
		);
		$this->add_responsive_control(
			'text_alignment',
			[
				'label' => esc_html__( "Text Alignment", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => aonsil_mascot_redux_text_alignment_list(),
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
			]
		);
		$this->add_control(
			'show_image',
			[
				'label' => esc_html__( "Show Icon/Image", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'show_title',
			[
				'label' => esc_html__( "Show Title", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'title_tag',
			[
				'label' => esc_html__( "Title Tag", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => aonsil_mascot_heading_tag_list(),
				'default' => 'h5'
			]
		);
		$this->add_control(
			'show_paragraph',
			[
				'label' => esc_html__( "Show Paragraph", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);
		$this->add_control(
			'show_button',
			[
				'label' => esc_html__( "Show Button", 'mascot-core-elementor' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'default' => 'yes'
			]
		);

		$this->end_controls_section();
	}

  /**
   * Render the widget output on the frontend.
   *
   * Written in PHP and used to generate the final HTML.
   *
   * @since 1.0.0
   *
   * @access protected
   */
  protected function render() {
	$settings = $this->get_settings_for_display();

	//classes
	$classes = array();
	if( $settings['design_style'] ) {
	  $classes[] = 'features-box-' . $settings['design_style'];
	}
	if( $settings['text_alignment'] ) {
	  $classes[] = $settings['text_alignment'];
	}
	if( $settings['featured_image_hover']['id'] ) {
	  $classes[] = 'has-featured-image-hover';
	}
	$classes[] = $settings['custom_css_class'];
	$settings['classes'] = $classes;
	$settings['settings'] = $settings;

	//Produce HTML version by using the parameters (filename, variation, folder name, parameters, shortcode_ob_start)
	$html = mascot_core_aonsil_elementor_get_shortcode_template_part( 'features-box', $settings['design_style'], 'features-box/tpl', $settings, true );


	echo $html;
  }
}
